unit SystemInfoUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls, ComCtrls, ToolWin, ImgList, Menus, Buttons,
  IpHlpApi, IpTypes, IpIfConst;

type
  TSystemInfoForm = class(TForm)
    ImageList1: TImageList;
    PageControl1: TPageControl;
    TabSheet1: TTabSheet;
    Panel2: TPanel;
    Label2: TLabel;
    Label3: TLabel;
    HostNameLabel: TLabel;
    Label4: TLabel;
    NodeTypeLabel: TLabel;
    Label5: TLabel;
    NetBIOSScopeLabel: TLabel;
    Label7: TLabel;
    IPRoutingLabel: TLabel;
    Label6: TLabel;
    WINSProxyLabel: TLabel;
    Label8: TLabel;
    NetBIOSResolutionLabel: TLabel;
    TabSheet3: TTabSheet;
    Panel3: TPanel;
    DNSListBox: TListBox;
    ScrollBox1: TScrollBox;
    Label10: TLabel;
    Label11: TLabel;
    DescriptionLabel: TLabel;
    PhysicaladdressLabel: TLabel;
    Label12: TLabel;
    AdapterTypeLabel: TLabel;
    AdapterNameLabel: TLabel;
    Label15: TLabel;
    Label13: TLabel;
    DHCPLabel: TLabel;
    Label16: TLabel;
    GatewayLabel: TLabel;
    DHCPServerLabel: TLabel;
    Label19: TLabel;
    Label18: TLabel;
    PrimaryWINSLabel: TLabel;
    SecondaryWINSLabel: TLabel;
    Label21: TLabel;
    IPListView: TListView;
    Panel1: TPanel;
    AdapterCB: TComboBox;
    procedure PageControl1Change(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure AdapterCBChange(Sender: TObject);
  private
    { Private declarations }
    procedure GetIPInfo;
    procedure GetAdapterInfo;
  public
    { Public declarations }
  end;

var
  SystemInfoForm: TSystemInfoForm;

implementation

{$R *.DFM}

procedure TSystemInfoForm.PageControl1Change(Sender: TObject);
begin
 if PageControl1.ActivePageIndex=0 then
  GetIPInfo;

 if PageControl1.ActivePageIndex=1 then
  GetAdapterInfo;
end;

procedure TSystemInfoForm.GetIPInfo;
var
 FixedInfoSize, Err, AdapterInfoSize:DWORD;
 pFixedInfo:PFIXED_INFO;
 pAdapterInfo, pAdapt:PIP_ADAPTER_INFO;
 pAddrStr:PIP_ADDR_STRING;
begin
 FixedInfoSize:=0;
 Err:=GetNetworkParams(nil, FixedInfoSize);

 if (Err<>0) and (Err<>ERROR_BUFFER_OVERFLOW) then
  begin
   HostNameLabel.Caption:='Error';
   exit;
  end;

 pFixedInfo:=PFIXED_INFO(GlobalAlloc(GPTR, FixedInfoSize));
 GetNetworkParams(pFixedInfo, FixedInfoSize);

 HostNameLabel.Caption:=StrPas(pFixedInfo.HostName);

 DNSListBox.Items.Clear;
 DNSListBox.Items.Add(StrPas(pFixedInfo.DnsServerList.IpAddress.S));

 pAddrStr:=pFixedInfo.DnsServerList.Next;

 while (pAddrStr<>nil) do
  begin
    DNSListBox.Items.Add(StrPas(pAddrStr.IpAddress.S));
   pAddrStr:=pAddrStr.Next;
  end;

 case pFixedInfo.NodeType of
  1: NodeTypeLabel.Caption:='Broadcast';
  2: NodeTypeLabel.Caption:='Peer to peer';
  4: NodeTypeLabel.Caption:='Mixed';
  8: NodeTypeLabel.Caption:='Hybrid';
 end;

 NetBIOSScopeLabel.Caption:=pFixedInfo.ScopeId;

 if pFixedInfo.EnableRouting>0 then
  IPRoutingLabel.Caption:='Yes'
 else
  IPRoutingLabel.Caption:='No';

 if pFixedInfo.EnableProxy>0 then
  WINSProxyLabel.Caption:='Yes'
 else
  WINSProxyLabel.Caption:='No';

 if pFixedInfo.EnableDns>0 then
  NetBIOSResolutionLabel.Caption:='Yes'
 else
  NetBIOSResolutionLabel.Caption:='No';
end;

procedure TSystemInfoForm.FormShow(Sender: TObject);
var
 pAdapterInfo, pAdapt:PIP_ADAPTER_INFO;
 pAddrStr:PIP_ADDR_STRING;
begin
 PageControl1.ActivePageIndex:=0;
 GetIPInfo;

 //Get Adapter Info
 AdapterCB.Items.Clear;
 AdapterInfoSize:=0;
 Err:=GetAdaptersInfo(nil, AdapterInfoSize);

 if (Err<>0) and (Err<>ERROR_BUFFER_OVERFLOW) then
  begin
   AdapterCB.Items.Add('Error');
   exit;
  end;

 pAdapterInfo := PIP_ADAPTER_INFO(GlobalAlloc(GPTR, AdapterInfoSize));
 GetAdaptersInfo(pAdapterInfo, AdapterInfoSize);
 pAdapt := pAdapterInfo;

 while pAdapt<>nil do
  begin
   case pAdapt.Type_ of
    MIB_IF_TYPE_ETHERNET:
     AdapterCB.Items.Add('Ethernet adapter '+pAdapt.AdapterName);
    MIB_IF_TYPE_TOKENRING:
     AdapterCB.Items.Add('Token Ring adapter '+pAdapt.AdapterName);
    MIB_IF_TYPE_FDDI:
     AdapterCB.Items.Add('FDDI adapter '+pAdapt.AdapterName);
    MIB_IF_TYPE_PPP:
     AdapterCB.Items.Add('PPP adapter '+pAdapt.AdapterName);
    MIB_IF_TYPE_LOOPBACK:
     AdapterCB.Items.Add('Loopback adapter '+pAdapt.AdapterName);
    MIB_IF_TYPE_SLIP:
     AdapterCB.Items.Add('Slip adapter '+pAdapt.AdapterName);
    MIB_IF_TYPE_OTHER:
     AdapterCB.Items.Add('Other adapter '+pAdapt.AdapterName);
   end;
   pAdapt := pAdapt.Next;
  end;
 GlobalFree(Cardinal(pFixedInfo));
end;

procedure TSystemInfoForm.GetAdapterInfo;
var
 Err, AdapterInfoSize:DWORD;
 pAdapterInfo, pAdapt:PIP_ADAPTER_INFO;
 Str:String;
 i:Integer;
 pAddrStr:PIP_ADDR_STRING;
begin
 AdapterTypeLabel.Caption:='';
 AdapterNameLabel.Caption:='';
 DescriptionLabel.Caption:='';
 PhysicaladdressLabel.Caption:='';
 IPListView.Clear;
 GatewayLabel.Caption:='';
 DHCPLabel.Caption:='';
 DHCPServerLabel.Caption:='';
 SecondaryWINSLabel.Caption:='';
 PrimaryWINSLabel.Caption:='';

 AdapterInfoSize:=0;
 Err:=GetAdaptersInfo(nil, AdapterInfoSize);

 if (Err<>0) and (Err<>ERROR_BUFFER_OVERFLOW) then
  begin
   AdapterCB.Items.Add('Error');
   exit;
  end;

 pAdapterInfo := PIP_ADAPTER_INFO(GlobalAlloc(GPTR, AdapterInfoSize));
 GetAdaptersInfo(pAdapterInfo, AdapterInfoSize);
 pAdapt := pAdapterInfo;

 while pAdapt<>nil do
  begin
   if Str+pAdapt.AdapterName<>AdapterCB.Text then
    begin
     pAdapt := pAdapt.Next;
     Continue;
    end;

    AdapterTypeLabel.Caption:=Str;
    AdapterNameLabel.Caption:=AdapterCB.Text;
    DescriptionLabel.Caption:=pAdapt.Description;

    Str:='';
    for i:=0 to pAdapt.AddressLength-1 do
     begin
      Str:=Str+IntToHex(pAdapt.Address[i],2);
      if i<>pAdapt.AddressLength-1 then
       Str:=Str+'-';
     end;
    PhysicaladdressLabel.Caption:=Str;

    pAddrStr:=@pAdapt.IpAddressList;
    while pAddrStr<>nil do
     begin
      with IPListView.Items.Add do
       begin
        Caption:=pAddrStr.IpAddress.S;
        SubItems.Add(pAddrStr.IpMask.S);
       end;
      pAddrStr := pAddrStr.Next;
     end;

    if pAdapt.DhcpEnabled=0 then
     DHCPLabel.Caption:='no'
    else
     DHCPLabel.Caption:='yes';

    DHCPServerLabel.Caption:=pAdapt.DhcpServer.IpAddress.S;
    PrimaryWINSLabel.Caption:=pAdapt.PrimaryWinsServer.IpAddress.S;
    SecondaryWINSLabel.Caption:=pAdapt.SecondaryWinsServer.IpAddress.S;
    GatewayLabel.Caption:=pAdapt.GatewayList.IpAddress.S;
    break;
  end;
 GlobalFree(Cardinal(pAdapterInfo));
end;

procedure TSystemInfoForm.AdapterCBChange(Sender: TObject);
begin
 GetAdapterInfo;
end;

end.
